#!/bin/bash
#
#SBATCH --share
#SBATCH --get-user-env 
#SBATCH --job-name=job_3
#SBATCH --output=/home/guests/jir2004/perlmodule/Runner-Init/dev/testpar/slurm_logs_2015_01_14T05_10_22.log/job_3.log

#SBATCH --partition=hpc


#SBATCH --nodelist=hpc007

#SBATCH --cpus-per-task=4

#SBATCH --dependency=afterok:50610 




cd /data/home/jir2004/perlmodule/Runner-Init/dev
mcerunner.pl --procs 4 --infile /home/guests/jir2004/perlmodule/Runner-Init/dev/testpar/job_3.in --outdir /home/guests/jir2004/perlmodule/Runner-Init/dev/testpar --logname job_3
